==> was-plugin-5.0.0.jar: was/jms/discover-inspect-sib-queue.py <==
#

def discoverSibQueues(c):
    print "Retrieving list of %s objects in container %s" % (prototype.wasType, c.name)
    cid = AdminConfig.getid(c.containmentPath)
    queues = ""
    try:
        queues = AdminTask.listSIBJMSQueues(cid)
    except:
        print "WARNING: Unable to discover SIBJMSQueue on container with id: %s"%(cid)
    if queues != "":
        for queue in queues.splitlines():
            deployedName = AdminConfig.showAttribute(queue, 'name')
            deployedId = c.id + '/' + deployedName
            discovered(deployedId, prototype.type)
            inspectSibQueue(deployedId, deployedName, queue, c)
            inspectedItem(deployedId)

def inspectSibQueue(deployedId, depoyedName, queueId, c):
    print "Inspecting", deployedId, "from ", queueId
    inspectedProperty(deployedId, 'jndiName', AdminConfig.showAttribute(queueId, 'jndiName'))
    inspectedProperty(deployedId, 'description', AdminConfig.showAttribute(queueId, 'description'))
    properties = AdminConfig.showAttribute(queueId, 'properties')[1:-1].split(' ')
    for p in properties:
        pname = AdminConfig.showAttribute(p, 'name')
        pname = pname[0:1].lower() + pname[1:]
        pvalue = AdminConfig.showAttribute(p, 'value')
        if pvalue == None:
            continue
        if pname == 'queueName':
            pvalue = getSibQueueDestinationId(findSibQueueDestination(pvalue))
        inspectedProperty(deployedId, pname, pvalue)

for c in findAllContainers(container):
    discoverSibQueues(c)

==> was-plugin-24.1.2.jar: was/jms/discover-inspect-sib-queue.py <==
#

def discoverSibQueues(c):
    print "Retrieving list of %s objects in container %s" % (prototype.wasType, c.name)
    cid = AdminConfig.getid(c.containmentPath)
    queues = ""
    try:
        queues = AdminTask.listSIBJMSQueues(cid)
    except:
        print "WARNING: Unable to discover SIBJMSQueue on container with id: %s"%(cid)
    if queues != "":
        for queue in queues.splitlines():
            deployedName = AdminConfig.showAttribute(queue, 'name')
            if appendTypeToName:
                deployedId = c.id + '/' + deployedName + '_' + prototype.type
            else:
                deployedId = c.id + '/' + deployedName
            discovered(deployedId, prototype.type)
            inspectedProperty(deployedId, 'wasName', deployedName)
            inspectSibQueue(deployedId, deployedName, queue, c)
            inspectedItem(deployedId)

def inspectSibQueue(deployedId, depoyedName, queueId, c):
    print "Inspecting", deployedId, "from ", queueId
    inspectedProperty(deployedId, 'jndiName', AdminConfig.showAttribute(queueId, 'jndiName'))
    inspectedProperty(deployedId, 'description', AdminConfig.showAttribute(queueId, 'description'))
    properties = AdminConfig.showAttribute(queueId, 'properties')[1:-1].split(' ')
    for p in properties:
        pname = AdminConfig.showAttribute(p, 'name')
        pname = pname[0:1].lower() + pname[1:]
        pvalue = AdminConfig.showAttribute(p, 'value')
        if pvalue == None:
            continue
        if pname == 'queueName':
            pname = 'queueDestinationName'
        inspectedProperty(deployedId, pname, pvalue)

for c in findAllContainers(container):
    discoverSibQueues(c)
